# -*- coding: utf-8 -*-
# Copyright (C) 2014-2021  EDF R&D
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

"""problème de fissure non plane, débouchante non normale"""

import os
import logging

from blocFissure import gmu
from blocFissure.gmu.geomsmesh import geompy
from blocFissure.gmu.genereMeshCalculZoneDefaut import genereMeshCalculZoneDefaut

from .ellipse_1 import ellipse_1

class ellipse_2(ellipse_1):
  """problème de fissure non plane, débouchante non normale"""

  nomProbleme = "ellipse_2"

  # ---------------------------------------------------------------------------
  def genereShapeFissure( self, geometriesSaines, geomParams, shapeFissureParams, \
                                mailleur="MeshGems"):
    """Importe la géométrie de la fissure"""
    texte = "genereShapeFissure pour '{}'".format(self.nomCas)
    logging.info(texte)

    lgInfluence = shapeFissureParams['lgInfluence']

    shellFiss = geompy.ImportBREP(os.path.join(gmu.pathBloc, "materielCasTests", "ellipse_1_pb.brep"))
    fondFiss = geompy.CreateGroup(shellFiss, geompy.ShapeType["EDGE"])
    geompy.UnionIDs(fondFiss, [3])
    geompy.addToStudy( shellFiss, 'shellFiss' )
    geompy.addToStudyInFather( shellFiss, fondFiss, 'fondFiss' )

    mailleur = self.mailleur2d3d()
    coordsNoeudsFissure = genereMeshCalculZoneDefaut(shellFiss, 5 ,25, mailleur, self.numeroCas)

    centre = None

    return [shellFiss, centre, lgInfluence, coordsNoeudsFissure, fondFiss]

  # ---------------------------------------------------------------------------
  def setReferencesMaillageFissure(self):
    from salome.smesh import smeshBuilder
    if smeshBuilder.NETGEN_VERSION_MAJOR < 6:
      self.referencesMaillageFissure = dict( \
                                             Entity_Quad_Quadrangle = 1748, \
                                             Entity_Quad_Hexa = 3795, \
                                             Entity_Node = 22219, \
                                             Entity_Quad_Edge = 258, \
                                             Entity_Quad_Triangle = 434, \
                                             Entity_Quad_Tetra = 2574, \
                                             Entity_Quad_Pyramid = 199, \
                                             Entity_Quad_Penta = 120 \
      )
    else:
      self.referencesMaillageFissure = dict( \
                                             Entity_Quad_Quadrangle = 1748, \
                                             Entity_Quad_Hexa = 3795, \
                                             Entity_Node = 22022, \
                                             Entity_Quad_Edge = 258, \
                                             Entity_Quad_Triangle = 412, \
                                             Entity_Quad_Tetra = 2442, \
                                             Entity_Quad_Pyramid = 199, \
                                             Entity_Quad_Penta = 120 \
      )
    
